@@ -19,6 +19,27 @@ kSchedulers = ['asynchyperband', 'bohbhyperband', 'pbt']
 kMetricMode = ['min', 'max']
 
 
+kConfigDefaults = {
+    'hpo':{
+        "algorithm": "random",
+        "metric": "loss",
+        "mode": "min",
+        "scheduler": "asynchyperband",
+        "log_dir": "./log",
+        "n_trial": 100,
+        "max_concurrent": 3,
+        "stopping": {"training_iteration": 1},
+        "scheduler_param": None,
+        "algorithm_param": None,
+        "model_param": None
+    },
+    'grid': {
+        "site": ['ANALY_MANC_GPU_TEST', 'ANALY_MWT2_GPU', 'ANALY_BNL_GPU_ARC'],
+        "container": '/cvmfs/unpacked.cern.ch/gitlab-registry.cern.ch/aml/hyperparameter-optimization/alkaid-qt/hpogrid:latest'
+    }
+}
+
+
 kDefaultSearchAlgorithm = 'random'
 kDefaultMetric = 'loss'
 kDefaultMode = 'min'
