@@ -316,8 +316,7 @@ class JobBuilder():
                 local_dir=self.log_dir,
                 stop=self.stop,
                 sync_to_driver=False,
-                fail_fast=True,
-                raise_on_failed_trial=False)
+                verbose=2)
         finally:
             ray.shutdown()
 
