@@ -62,7 +62,7 @@ class ConfigurationBase():
             config_type = self.config_type
             
         if config_type == 'project':
-            base_dir = os.path.join(os.environ[kHPOGridEnvPath], 'project')
+            base_dir = os.path.join(os.environ[kHPOGridEnvPath], 'projects')
         else:
             base_dir = os.path.join(os.environ[kHPOGridEnvPath], 'config', config_type)
 
