@@ -49,9 +49,4 @@ class SearchSpaceConfiguration(ConfigurationBase):
         
         if validation.validate_search_space(search_space):
             self.save(search_space, config_name, action)
-        return search_space
-    
-    def show(self, name):
-        config = self.load_config(name)
-        table = stylus.create_formated_dict(config, self.show_columns, indexed=False)
-        print(table)    
\ No newline at end of file
+        return search_space
\ No newline at end of file
